<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!-- bookindex.xsl - 08/28/05 - version 1.01
      John J. Couture
      San Diego Miramar College

     XSL Stylesheet for transforming the Table of Contents of
     Al Williams Book "Exploring the SX Microcontroller with
     Assembly & BASIC Programming Version 3.0 
     into a single page index sheet.  

     XML data file (bookindex.xml) is structured as: 
        Root>
           Row>
              topic>
              page>
              isbn>

     XSL does not have a FOR / NEXT statement so you have to 
     trick it by using recursive calls to emulate the FOR / NEXT 

     The xsl:template is similar to a function structure.

   ***************************************
   Main Program
   This program sets up the HTML table and 
    builds three columns with data from successive
    records from the XML dataset.

    Based on a font size of 12px it seemed that about
    45 lines fit per column on a page.
   ******************************************* -->
	<!-- Main Program ******************************* -->
	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:apply-templates select="root"/>
				</title>
				<style>
                  h1 {   font-size: 18px; }   
                  td  {   font-size: 12px; }
                </style>
			</head>
			<body style="font-family: Arial;">
				<h1>Index, Exploring the SX Microcontroller w/ Asm &amp; BASIC ver 3.0, Al Williams</h1>
				<table border="0" cellpadding="5">
					<tr>
						<td valign="top">
							<table border="0">
								<tr>
									<th align="left">topic</th>
									<th>page</th>
								</tr>
								<tr>
									<xsl:call-template name="Inside">
										<xsl:with-param name="i">0</xsl:with-param>
										<xsl:with-param name="count">44</xsl:with-param>
									</xsl:call-template>
								</tr>
							</table>
						</td>
						<td valign="top">
							<table border="0">
								<tr>
									<th align="left">topic</th>
									<th>page</th>
								</tr>
								<tr>
									<xsl:call-template name="Inside">
										<xsl:with-param name="i">45</xsl:with-param>
										<xsl:with-param name="count">89</xsl:with-param>
									</xsl:call-template>
								</tr>
							</table>
						</td>
						<td valign="top">
							<table border="0">
								<tr>
									<th align="left">topic</th>
									<th>page</th>
								</tr>
								<tr>
									<xsl:call-template name="Inside">
										<xsl:with-param name="i">90</xsl:with-param>
										<xsl:with-param name="count">134</xsl:with-param>
									</xsl:call-template>
								</tr>
							</table>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>
	<!-- 
    ***************************************
    Inside Loop (iterate "count" lines)
    ******************************************* 
    -->
	<xsl:template name="Inside">
		<xsl:param name="i"/>
		<xsl:param name="count"/>
		<xsl:if test="$i &lt;= $count">
			<tr>
				<!-- <td><xsl:value-of select="$i+1" /></td> -->
				<td>
					<xsl:value-of select="Root/Row[$i+1]/topic"/>
				</td>
				<td>
					<xsl:value-of select="Root/Row[$i+1]/page"/>
				</td>
			</tr>
		</xsl:if>
		<!-- 
         ***************************************
         Recurisive Call to itself if I < Count
         *************************************** 
         -->
		<xsl:if test="$i &lt;= $count">
			<xsl:call-template name="Inside">
				<xsl:with-param name="i">
					<xsl:value-of select="$i + 1"/>
				</xsl:with-param>
				<xsl:with-param name="count">
					<xsl:value-of select="$count"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	
</xsl:stylesheet>
